% 140x84 oversized Macaulay multiresultant matrix for 4 point
% DLT-like pose method, found by taking all monomials of degree 6
% instead of 5. Rank degeneracy is still 4 for planar case, so no gain.

% Using the DLT on 4 known 3D points, the possible projection matrices
% have been reduced to a 4 parameter family P = u1*P1+..+u4*P4 where
% (u1..u4) are unknown parameters.  We use 4 supplementary calibration
% constraints aspect_ratio = 1, skew=0, principal_point=(0,0) (i.e.
% w(1,1)-w(2,2) = w(1,2) = w(1,3) = w(2,3) = 0 where w is the DIAC) to
% eliminate (u1..u4) and solve for P, camera pose, calibration, etc.
% The redundancy is 1 (since u1..u4 are only defined up to scale), so a
% linear solution is possible.  The constraints are all quadratic in
% (u1..u4). Each row of the 4x10 input matrix M represents one of these
% homogeneous quadratics (i.e. it is a flattened 4x4 symmetric
% matrix). The output multiresultant matrix has rank 79 in the noiseless
% case (but alas only 76 for coplanar points). The last 4 components of
% its null vector are (...u1..u4), which in turn gives P, pose, etc. The
% matrix was calculated with Maple using my extended multiresultant
% routine xmultires().

function [u,cond] = dlt4multires84(M);
   n = 140;
   m = 84;
   A = zeros(n,m);
      A(1,21) = M(1,1);
      A(2,35) = M(1,1);
      A(3,9) = M(1,1);
      A(4,19) = M(1,1);
      A(5,7) = M(1,1);
      A(6,13) = M(1,1);
      A(7,28) = M(1,1);
      A(8,30) = M(1,1);
      A(9,32) = M(1,1);
      A(10,18) = M(1,1);
      A(11,16) = M(1,1);
      A(12,34) = M(1,1);
      A(13,33) = M(1,1);
      A(14,23) = M(1,1);
      A(15,26) = M(1,1);
      A(16,25) = M(1,1);
      A(17,29) = M(1,1);
      A(18,15) = M(1,1);
      A(19,8) = M(1,1);
      A(20,24) = M(1,1);
      A(21,11) = M(1,1);
      A(22,27) = M(1,1);
      A(23,22) = M(1,1);
      A(24,12) = M(1,1);
      A(25,6) = M(1,1);
      A(26,14) = M(1,1);
      A(27,4) = M(1,1);
      A(28,10) = M(1,1);
      A(29,3) = M(1,1);
      A(30,20) = M(1,1);
      A(31,17) = M(1,1);
      A(32,2) = M(1,1);
      A(33,5) = M(1,1);
      A(34,1) = M(1,1);
      A(35,31) = M(1,1);
      A(1,36) = M(1,2);
      A(2,50) = M(1,2);
      A(3,15) = M(1,2);
      A(4,29) = M(1,2);
      A(5,13) = M(1,2);
      A(6,23) = M(1,2);
      A(7,43) = M(1,2);
      A(8,45) = M(1,2);
      A(9,47) = M(1,2);
      A(10,28) = M(1,2);
      A(11,26) = M(1,2);
      A(12,49) = M(1,2);
      A(13,48) = M(1,2);
      A(14,38) = M(1,2);
      A(15,41) = M(1,2);
      A(16,40) = M(1,2);
      A(17,44) = M(1,2);
      A(18,25) = M(1,2);
      A(19,14) = M(1,2);
      A(20,39) = M(1,2);
      A(21,21) = M(1,2);
      A(22,42) = M(1,2);
      A(23,37) = M(1,2);
      A(24,22) = M(1,2);
      A(25,12) = M(1,2);
      A(26,24) = M(1,2);
      A(27,7) = M(1,2);
      A(28,16) = M(1,2);
      A(29,6) = M(1,2);
      A(30,30) = M(1,2);
      A(31,27) = M(1,2);
      A(32,5) = M(1,2);
      A(33,11) = M(1,2);
      A(34,2) = M(1,2);
      A(35,46) = M(1,2);
      A(1,57) = M(1,3);
      A(2,71) = M(1,3);
      A(3,25) = M(1,3);
      A(4,44) = M(1,3);
      A(5,23) = M(1,3);
      A(6,38) = M(1,3);
      A(7,64) = M(1,3);
      A(8,66) = M(1,3);
      A(9,68) = M(1,3);
      A(10,43) = M(1,3);
      A(11,41) = M(1,3);
      A(12,70) = M(1,3);
      A(13,69) = M(1,3);
      A(14,59) = M(1,3);
      A(15,62) = M(1,3);
      A(16,61) = M(1,3);
      A(17,65) = M(1,3);
      A(18,40) = M(1,3);
      A(19,24) = M(1,3);
      A(20,60) = M(1,3);
      A(21,36) = M(1,3);
      A(22,63) = M(1,3);
      A(23,58) = M(1,3);
      A(24,37) = M(1,3);
      A(25,22) = M(1,3);
      A(26,39) = M(1,3);
      A(27,13) = M(1,3);
      A(28,26) = M(1,3);
      A(29,12) = M(1,3);
      A(30,45) = M(1,3);
      A(31,42) = M(1,3);
      A(32,11) = M(1,3);
      A(33,21) = M(1,3);
      A(34,5) = M(1,3);
      A(35,67) = M(1,3);
      A(1,37) = M(1,4);
      A(2,55) = M(1,4);
      A(3,18) = M(1,4);
      A(4,33) = M(1,4);
      A(5,15) = M(1,4);
      A(6,25) = M(1,4);
      A(7,47) = M(1,4);
      A(8,49) = M(1,4);
      A(9,52) = M(1,4);
      A(10,32) = M(1,4);
      A(11,29) = M(1,4);
      A(12,54) = M(1,4);
      A(13,53) = M(1,4);
      A(14,40) = M(1,4);
      A(15,44) = M(1,4);
      A(16,43) = M(1,4);
      A(17,48) = M(1,4);
      A(18,28) = M(1,4);
      A(19,17) = M(1,4);
      A(20,42) = M(1,4);
      A(21,22) = M(1,4);
      A(22,46) = M(1,4);
      A(23,39) = M(1,4);
      A(24,24) = M(1,4);
      A(25,14) = M(1,4);
      A(26,27) = M(1,4);
      A(27,9) = M(1,4);
      A(28,19) = M(1,4);
      A(29,8) = M(1,4);
      A(30,34) = M(1,4);
      A(31,31) = M(1,4);
      A(32,6) = M(1,4);
      A(33,12) = M(1,4);
      A(34,3) = M(1,4);
      A(35,51) = M(1,4);
      A(1,58) = M(1,5);
      A(2,76) = M(1,5);
      A(3,28) = M(1,5);
      A(4,48) = M(1,5);
      A(5,25) = M(1,5);
      A(6,40) = M(1,5);
      A(7,68) = M(1,5);
      A(8,70) = M(1,5);
      A(9,73) = M(1,5);
      A(10,47) = M(1,5);
      A(11,44) = M(1,5);
      A(12,75) = M(1,5);
      A(13,74) = M(1,5);
      A(14,61) = M(1,5);
      A(15,65) = M(1,5);
      A(16,64) = M(1,5);
      A(17,69) = M(1,5);
      A(18,43) = M(1,5);
      A(19,27) = M(1,5);
      A(20,63) = M(1,5);
      A(21,37) = M(1,5);
      A(22,67) = M(1,5);
      A(23,60) = M(1,5);
      A(24,39) = M(1,5);
      A(25,24) = M(1,5);
      A(26,42) = M(1,5);
      A(27,15) = M(1,5);
      A(28,29) = M(1,5);
      A(29,14) = M(1,5);
      A(30,49) = M(1,5);
      A(31,46) = M(1,5);
      A(32,12) = M(1,5);
      A(33,22) = M(1,5);
      A(34,6) = M(1,5);
      A(35,72) = M(1,5);
      A(1,60) = M(1,6);
      A(2,82) = M(1,6);
      A(3,32) = M(1,6);
      A(4,53) = M(1,6);
      A(5,28) = M(1,6);
      A(6,43) = M(1,6);
      A(7,73) = M(1,6);
      A(8,75) = M(1,6);
      A(9,79) = M(1,6);
      A(10,52) = M(1,6);
      A(11,48) = M(1,6);
      A(12,81) = M(1,6);
      A(13,80) = M(1,6);
      A(14,64) = M(1,6);
      A(15,69) = M(1,6);
      A(16,68) = M(1,6);
      A(17,74) = M(1,6);
      A(18,47) = M(1,6);
      A(19,31) = M(1,6);
      A(20,67) = M(1,6);
      A(21,39) = M(1,6);
      A(22,72) = M(1,6);
      A(23,63) = M(1,6);
      A(24,42) = M(1,6);
      A(25,27) = M(1,6);
      A(26,46) = M(1,6);
      A(27,18) = M(1,6);
      A(28,33) = M(1,6);
      A(29,17) = M(1,6);
      A(30,54) = M(1,6);
      A(31,51) = M(1,6);
      A(32,14) = M(1,6);
      A(33,24) = M(1,6);
      A(34,8) = M(1,6);
      A(35,78) = M(1,6);
      A(1,38) = M(1,7);
      A(2,56) = M(1,7);
      A(3,19) = M(1,7);
      A(4,34) = M(1,7);
      A(5,16) = M(1,7);
      A(6,26) = M(1,7);
      A(7,48) = M(1,7);
      A(8,50) = M(1,7);
      A(9,53) = M(1,7);
      A(10,33) = M(1,7);
      A(11,30) = M(1,7);
      A(12,55) = M(1,7);
      A(13,54) = M(1,7);
      A(14,41) = M(1,7);
      A(15,45) = M(1,7);
      A(16,44) = M(1,7);
      A(17,49) = M(1,7);
      A(18,29) = M(1,7);
      A(19,18) = M(1,7);
      A(20,43) = M(1,7);
      A(21,23) = M(1,7);
      A(22,47) = M(1,7);
      A(23,40) = M(1,7);
      A(24,25) = M(1,7);
      A(25,15) = M(1,7);
      A(26,28) = M(1,7);
      A(27,10) = M(1,7);
      A(28,20) = M(1,7);
      A(29,9) = M(1,7);
      A(30,35) = M(1,7);
      A(31,32) = M(1,7);
      A(32,7) = M(1,7);
      A(33,13) = M(1,7);
      A(34,4) = M(1,7);
      A(35,52) = M(1,7);
      A(1,59) = M(1,8);
      A(2,77) = M(1,8);
      A(3,29) = M(1,8);
      A(4,49) = M(1,8);
      A(5,26) = M(1,8);
      A(6,41) = M(1,8);
      A(7,69) = M(1,8);
      A(8,71) = M(1,8);
      A(9,74) = M(1,8);
      A(10,48) = M(1,8);
      A(11,45) = M(1,8);
      A(12,76) = M(1,8);
      A(13,75) = M(1,8);
      A(14,62) = M(1,8);
      A(15,66) = M(1,8);
      A(16,65) = M(1,8);
      A(17,70) = M(1,8);
      A(18,44) = M(1,8);
      A(19,28) = M(1,8);
      A(20,64) = M(1,8);
      A(21,38) = M(1,8);
      A(22,68) = M(1,8);
      A(23,61) = M(1,8);
      A(24,40) = M(1,8);
      A(25,25) = M(1,8);
      A(26,43) = M(1,8);
      A(27,16) = M(1,8);
      A(28,30) = M(1,8);
      A(29,15) = M(1,8);
      A(30,50) = M(1,8);
      A(31,47) = M(1,8);
      A(32,13) = M(1,8);
      A(33,23) = M(1,8);
      A(34,7) = M(1,8);
      A(35,73) = M(1,8);
      A(1,61) = M(1,9);
      A(2,83) = M(1,9);
      A(3,33) = M(1,9);
      A(4,54) = M(1,9);
      A(5,29) = M(1,9);
      A(6,44) = M(1,9);
      A(7,74) = M(1,9);
      A(8,76) = M(1,9);
      A(9,80) = M(1,9);
      A(10,53) = M(1,9);
      A(11,49) = M(1,9);
      A(12,82) = M(1,9);
      A(13,81) = M(1,9);
      A(14,65) = M(1,9);
      A(15,70) = M(1,9);
      A(16,69) = M(1,9);
      A(17,75) = M(1,9);
      A(18,48) = M(1,9);
      A(19,32) = M(1,9);
      A(20,68) = M(1,9);
      A(21,40) = M(1,9);
      A(22,73) = M(1,9);
      A(23,64) = M(1,9);
      A(24,43) = M(1,9);
      A(25,28) = M(1,9);
      A(26,47) = M(1,9);
      A(27,19) = M(1,9);
      A(28,34) = M(1,9);
      A(29,18) = M(1,9);
      A(30,55) = M(1,9);
      A(31,52) = M(1,9);
      A(32,15) = M(1,9);
      A(33,25) = M(1,9);
      A(34,9) = M(1,9);
      A(35,79) = M(1,9);
      A(1,62) = M(1,10);
      A(2,84) = M(1,10);
      A(3,34) = M(1,10);
      A(4,55) = M(1,10);
      A(5,30) = M(1,10);
      A(6,45) = M(1,10);
      A(7,75) = M(1,10);
      A(8,77) = M(1,10);
      A(9,81) = M(1,10);
      A(10,54) = M(1,10);
      A(11,50) = M(1,10);
      A(12,83) = M(1,10);
      A(13,82) = M(1,10);
      A(14,66) = M(1,10);
      A(15,71) = M(1,10);
      A(16,70) = M(1,10);
      A(17,76) = M(1,10);
      A(18,49) = M(1,10);
      A(19,33) = M(1,10);
      A(20,69) = M(1,10);
      A(21,41) = M(1,10);
      A(22,74) = M(1,10);
      A(23,65) = M(1,10);
      A(24,44) = M(1,10);
      A(25,29) = M(1,10);
      A(26,48) = M(1,10);
      A(27,20) = M(1,10);
      A(28,35) = M(1,10);
      A(29,19) = M(1,10);
      A(30,56) = M(1,10);
      A(31,53) = M(1,10);
      A(32,16) = M(1,10);
      A(33,26) = M(1,10);
      A(34,10) = M(1,10);
      A(35,80) = M(1,10);
      A(36,21) = M(2,1);
      A(37,35) = M(2,1);
      A(38,9) = M(2,1);
      A(39,19) = M(2,1);
      A(40,7) = M(2,1);
      A(41,13) = M(2,1);
      A(42,28) = M(2,1);
      A(43,30) = M(2,1);
      A(44,32) = M(2,1);
      A(45,18) = M(2,1);
      A(46,16) = M(2,1);
      A(47,34) = M(2,1);
      A(48,33) = M(2,1);
      A(49,23) = M(2,1);
      A(50,26) = M(2,1);
      A(51,25) = M(2,1);
      A(52,29) = M(2,1);
      A(53,15) = M(2,1);
      A(54,8) = M(2,1);
      A(55,24) = M(2,1);
      A(56,11) = M(2,1);
      A(57,27) = M(2,1);
      A(58,22) = M(2,1);
      A(59,12) = M(2,1);
      A(60,6) = M(2,1);
      A(61,14) = M(2,1);
      A(62,4) = M(2,1);
      A(63,10) = M(2,1);
      A(64,3) = M(2,1);
      A(65,20) = M(2,1);
      A(66,17) = M(2,1);
      A(67,2) = M(2,1);
      A(68,5) = M(2,1);
      A(69,1) = M(2,1);
      A(70,31) = M(2,1);
      A(36,36) = M(2,2);
      A(37,50) = M(2,2);
      A(38,15) = M(2,2);
      A(39,29) = M(2,2);
      A(40,13) = M(2,2);
      A(41,23) = M(2,2);
      A(42,43) = M(2,2);
      A(43,45) = M(2,2);
      A(44,47) = M(2,2);
      A(45,28) = M(2,2);
      A(46,26) = M(2,2);
      A(47,49) = M(2,2);
      A(48,48) = M(2,2);
      A(49,38) = M(2,2);
      A(50,41) = M(2,2);
      A(51,40) = M(2,2);
      A(52,44) = M(2,2);
      A(53,25) = M(2,2);
      A(54,14) = M(2,2);
      A(55,39) = M(2,2);
      A(56,21) = M(2,2);
      A(57,42) = M(2,2);
      A(58,37) = M(2,2);
      A(59,22) = M(2,2);
      A(60,12) = M(2,2);
      A(61,24) = M(2,2);
      A(62,7) = M(2,2);
      A(63,16) = M(2,2);
      A(64,6) = M(2,2);
      A(65,30) = M(2,2);
      A(66,27) = M(2,2);
      A(67,5) = M(2,2);
      A(68,11) = M(2,2);
      A(69,2) = M(2,2);
      A(70,46) = M(2,2);
      A(36,57) = M(2,3);
      A(37,71) = M(2,3);
      A(38,25) = M(2,3);
      A(39,44) = M(2,3);
      A(40,23) = M(2,3);
      A(41,38) = M(2,3);
      A(42,64) = M(2,3);
      A(43,66) = M(2,3);
      A(44,68) = M(2,3);
      A(45,43) = M(2,3);
      A(46,41) = M(2,3);
      A(47,70) = M(2,3);
      A(48,69) = M(2,3);
      A(49,59) = M(2,3);
      A(50,62) = M(2,3);
      A(51,61) = M(2,3);
      A(52,65) = M(2,3);
      A(53,40) = M(2,3);
      A(54,24) = M(2,3);
      A(55,60) = M(2,3);
      A(56,36) = M(2,3);
      A(57,63) = M(2,3);
      A(58,58) = M(2,3);
      A(59,37) = M(2,3);
      A(60,22) = M(2,3);
      A(61,39) = M(2,3);
      A(62,13) = M(2,3);
      A(63,26) = M(2,3);
      A(64,12) = M(2,3);
      A(65,45) = M(2,3);
      A(66,42) = M(2,3);
      A(67,11) = M(2,3);
      A(68,21) = M(2,3);
      A(69,5) = M(2,3);
      A(70,67) = M(2,3);
      A(36,37) = M(2,4);
      A(37,55) = M(2,4);
      A(38,18) = M(2,4);
      A(39,33) = M(2,4);
      A(40,15) = M(2,4);
      A(41,25) = M(2,4);
      A(42,47) = M(2,4);
      A(43,49) = M(2,4);
      A(44,52) = M(2,4);
      A(45,32) = M(2,4);
      A(46,29) = M(2,4);
      A(47,54) = M(2,4);
      A(48,53) = M(2,4);
      A(49,40) = M(2,4);
      A(50,44) = M(2,4);
      A(51,43) = M(2,4);
      A(52,48) = M(2,4);
      A(53,28) = M(2,4);
      A(54,17) = M(2,4);
      A(55,42) = M(2,4);
      A(56,22) = M(2,4);
      A(57,46) = M(2,4);
      A(58,39) = M(2,4);
      A(59,24) = M(2,4);
      A(60,14) = M(2,4);
      A(61,27) = M(2,4);
      A(62,9) = M(2,4);
      A(63,19) = M(2,4);
      A(64,8) = M(2,4);
      A(65,34) = M(2,4);
      A(66,31) = M(2,4);
      A(67,6) = M(2,4);
      A(68,12) = M(2,4);
      A(69,3) = M(2,4);
      A(70,51) = M(2,4);
      A(36,58) = M(2,5);
      A(37,76) = M(2,5);
      A(38,28) = M(2,5);
      A(39,48) = M(2,5);
      A(40,25) = M(2,5);
      A(41,40) = M(2,5);
      A(42,68) = M(2,5);
      A(43,70) = M(2,5);
      A(44,73) = M(2,5);
      A(45,47) = M(2,5);
      A(46,44) = M(2,5);
      A(47,75) = M(2,5);
      A(48,74) = M(2,5);
      A(49,61) = M(2,5);
      A(50,65) = M(2,5);
      A(51,64) = M(2,5);
      A(52,69) = M(2,5);
      A(53,43) = M(2,5);
      A(54,27) = M(2,5);
      A(55,63) = M(2,5);
      A(56,37) = M(2,5);
      A(57,67) = M(2,5);
      A(58,60) = M(2,5);
      A(59,39) = M(2,5);
      A(60,24) = M(2,5);
      A(61,42) = M(2,5);
      A(62,15) = M(2,5);
      A(63,29) = M(2,5);
      A(64,14) = M(2,5);
      A(65,49) = M(2,5);
      A(66,46) = M(2,5);
      A(67,12) = M(2,5);
      A(68,22) = M(2,5);
      A(69,6) = M(2,5);
      A(70,72) = M(2,5);
      A(36,60) = M(2,6);
      A(37,82) = M(2,6);
      A(38,32) = M(2,6);
      A(39,53) = M(2,6);
      A(40,28) = M(2,6);
      A(41,43) = M(2,6);
      A(42,73) = M(2,6);
      A(43,75) = M(2,6);
      A(44,79) = M(2,6);
      A(45,52) = M(2,6);
      A(46,48) = M(2,6);
      A(47,81) = M(2,6);
      A(48,80) = M(2,6);
      A(49,64) = M(2,6);
      A(50,69) = M(2,6);
      A(51,68) = M(2,6);
      A(52,74) = M(2,6);
      A(53,47) = M(2,6);
      A(54,31) = M(2,6);
      A(55,67) = M(2,6);
      A(56,39) = M(2,6);
      A(57,72) = M(2,6);
      A(58,63) = M(2,6);
      A(59,42) = M(2,6);
      A(60,27) = M(2,6);
      A(61,46) = M(2,6);
      A(62,18) = M(2,6);
      A(63,33) = M(2,6);
      A(64,17) = M(2,6);
      A(65,54) = M(2,6);
      A(66,51) = M(2,6);
      A(67,14) = M(2,6);
      A(68,24) = M(2,6);
      A(69,8) = M(2,6);
      A(70,78) = M(2,6);
      A(36,38) = M(2,7);
      A(37,56) = M(2,7);
      A(38,19) = M(2,7);
      A(39,34) = M(2,7);
      A(40,16) = M(2,7);
      A(41,26) = M(2,7);
      A(42,48) = M(2,7);
      A(43,50) = M(2,7);
      A(44,53) = M(2,7);
      A(45,33) = M(2,7);
      A(46,30) = M(2,7);
      A(47,55) = M(2,7);
      A(48,54) = M(2,7);
      A(49,41) = M(2,7);
      A(50,45) = M(2,7);
      A(51,44) = M(2,7);
      A(52,49) = M(2,7);
      A(53,29) = M(2,7);
      A(54,18) = M(2,7);
      A(55,43) = M(2,7);
      A(56,23) = M(2,7);
      A(57,47) = M(2,7);
      A(58,40) = M(2,7);
      A(59,25) = M(2,7);
      A(60,15) = M(2,7);
      A(61,28) = M(2,7);
      A(62,10) = M(2,7);
      A(63,20) = M(2,7);
      A(64,9) = M(2,7);
      A(65,35) = M(2,7);
      A(66,32) = M(2,7);
      A(67,7) = M(2,7);
      A(68,13) = M(2,7);
      A(69,4) = M(2,7);
      A(70,52) = M(2,7);
      A(36,59) = M(2,8);
      A(37,77) = M(2,8);
      A(38,29) = M(2,8);
      A(39,49) = M(2,8);
      A(40,26) = M(2,8);
      A(41,41) = M(2,8);
      A(42,69) = M(2,8);
      A(43,71) = M(2,8);
      A(44,74) = M(2,8);
      A(45,48) = M(2,8);
      A(46,45) = M(2,8);
      A(47,76) = M(2,8);
      A(48,75) = M(2,8);
      A(49,62) = M(2,8);
      A(50,66) = M(2,8);
      A(51,65) = M(2,8);
      A(52,70) = M(2,8);
      A(53,44) = M(2,8);
      A(54,28) = M(2,8);
      A(55,64) = M(2,8);
      A(56,38) = M(2,8);
      A(57,68) = M(2,8);
      A(58,61) = M(2,8);
      A(59,40) = M(2,8);
      A(60,25) = M(2,8);
      A(61,43) = M(2,8);
      A(62,16) = M(2,8);
      A(63,30) = M(2,8);
      A(64,15) = M(2,8);
      A(65,50) = M(2,8);
      A(66,47) = M(2,8);
      A(67,13) = M(2,8);
      A(68,23) = M(2,8);
      A(69,7) = M(2,8);
      A(70,73) = M(2,8);
      A(36,61) = M(2,9);
      A(37,83) = M(2,9);
      A(38,33) = M(2,9);
      A(39,54) = M(2,9);
      A(40,29) = M(2,9);
      A(41,44) = M(2,9);
      A(42,74) = M(2,9);
      A(43,76) = M(2,9);
      A(44,80) = M(2,9);
      A(45,53) = M(2,9);
      A(46,49) = M(2,9);
      A(47,82) = M(2,9);
      A(48,81) = M(2,9);
      A(49,65) = M(2,9);
      A(50,70) = M(2,9);
      A(51,69) = M(2,9);
      A(52,75) = M(2,9);
      A(53,48) = M(2,9);
      A(54,32) = M(2,9);
      A(55,68) = M(2,9);
      A(56,40) = M(2,9);
      A(57,73) = M(2,9);
      A(58,64) = M(2,9);
      A(59,43) = M(2,9);
      A(60,28) = M(2,9);
      A(61,47) = M(2,9);
      A(62,19) = M(2,9);
      A(63,34) = M(2,9);
      A(64,18) = M(2,9);
      A(65,55) = M(2,9);
      A(66,52) = M(2,9);
      A(67,15) = M(2,9);
      A(68,25) = M(2,9);
      A(69,9) = M(2,9);
      A(70,79) = M(2,9);
      A(36,62) = M(2,10);
      A(37,84) = M(2,10);
      A(38,34) = M(2,10);
      A(39,55) = M(2,10);
      A(40,30) = M(2,10);
      A(41,45) = M(2,10);
      A(42,75) = M(2,10);
      A(43,77) = M(2,10);
      A(44,81) = M(2,10);
      A(45,54) = M(2,10);
      A(46,50) = M(2,10);
      A(47,83) = M(2,10);
      A(48,82) = M(2,10);
      A(49,66) = M(2,10);
      A(50,71) = M(2,10);
      A(51,70) = M(2,10);
      A(52,76) = M(2,10);
      A(53,49) = M(2,10);
      A(54,33) = M(2,10);
      A(55,69) = M(2,10);
      A(56,41) = M(2,10);
      A(57,74) = M(2,10);
      A(58,65) = M(2,10);
      A(59,44) = M(2,10);
      A(60,29) = M(2,10);
      A(61,48) = M(2,10);
      A(62,20) = M(2,10);
      A(63,35) = M(2,10);
      A(64,19) = M(2,10);
      A(65,56) = M(2,10);
      A(66,53) = M(2,10);
      A(67,16) = M(2,10);
      A(68,26) = M(2,10);
      A(69,10) = M(2,10);
      A(70,80) = M(2,10);
      A(71,21) = M(3,1);
      A(72,35) = M(3,1);
      A(73,9) = M(3,1);
      A(74,19) = M(3,1);
      A(75,7) = M(3,1);
      A(76,13) = M(3,1);
      A(77,28) = M(3,1);
      A(78,30) = M(3,1);
      A(79,32) = M(3,1);
      A(80,18) = M(3,1);
      A(81,16) = M(3,1);
      A(82,34) = M(3,1);
      A(83,33) = M(3,1);
      A(84,23) = M(3,1);
      A(85,26) = M(3,1);
      A(86,25) = M(3,1);
      A(87,29) = M(3,1);
      A(88,15) = M(3,1);
      A(89,8) = M(3,1);
      A(90,24) = M(3,1);
      A(91,11) = M(3,1);
      A(92,27) = M(3,1);
      A(93,22) = M(3,1);
      A(94,12) = M(3,1);
      A(95,6) = M(3,1);
      A(96,14) = M(3,1);
      A(97,4) = M(3,1);
      A(98,10) = M(3,1);
      A(99,3) = M(3,1);
      A(100,20) = M(3,1);
      A(101,17) = M(3,1);
      A(102,2) = M(3,1);
      A(103,5) = M(3,1);
      A(104,1) = M(3,1);
      A(105,31) = M(3,1);
      A(71,36) = M(3,2);
      A(72,50) = M(3,2);
      A(73,15) = M(3,2);
      A(74,29) = M(3,2);
      A(75,13) = M(3,2);
      A(76,23) = M(3,2);
      A(77,43) = M(3,2);
      A(78,45) = M(3,2);
      A(79,47) = M(3,2);
      A(80,28) = M(3,2);
      A(81,26) = M(3,2);
      A(82,49) = M(3,2);
      A(83,48) = M(3,2);
      A(84,38) = M(3,2);
      A(85,41) = M(3,2);
      A(86,40) = M(3,2);
      A(87,44) = M(3,2);
      A(88,25) = M(3,2);
      A(89,14) = M(3,2);
      A(90,39) = M(3,2);
      A(91,21) = M(3,2);
      A(92,42) = M(3,2);
      A(93,37) = M(3,2);
      A(94,22) = M(3,2);
      A(95,12) = M(3,2);
      A(96,24) = M(3,2);
      A(97,7) = M(3,2);
      A(98,16) = M(3,2);
      A(99,6) = M(3,2);
      A(100,30) = M(3,2);
      A(101,27) = M(3,2);
      A(102,5) = M(3,2);
      A(103,11) = M(3,2);
      A(104,2) = M(3,2);
      A(105,46) = M(3,2);
      A(71,57) = M(3,3);
      A(72,71) = M(3,3);
      A(73,25) = M(3,3);
      A(74,44) = M(3,3);
      A(75,23) = M(3,3);
      A(76,38) = M(3,3);
      A(77,64) = M(3,3);
      A(78,66) = M(3,3);
      A(79,68) = M(3,3);
      A(80,43) = M(3,3);
      A(81,41) = M(3,3);
      A(82,70) = M(3,3);
      A(83,69) = M(3,3);
      A(84,59) = M(3,3);
      A(85,62) = M(3,3);
      A(86,61) = M(3,3);
      A(87,65) = M(3,3);
      A(88,40) = M(3,3);
      A(89,24) = M(3,3);
      A(90,60) = M(3,3);
      A(91,36) = M(3,3);
      A(92,63) = M(3,3);
      A(93,58) = M(3,3);
      A(94,37) = M(3,3);
      A(95,22) = M(3,3);
      A(96,39) = M(3,3);
      A(97,13) = M(3,3);
      A(98,26) = M(3,3);
      A(99,12) = M(3,3);
      A(100,45) = M(3,3);
      A(101,42) = M(3,3);
      A(102,11) = M(3,3);
      A(103,21) = M(3,3);
      A(104,5) = M(3,3);
      A(105,67) = M(3,3);
      A(71,37) = M(3,4);
      A(72,55) = M(3,4);
      A(73,18) = M(3,4);
      A(74,33) = M(3,4);
      A(75,15) = M(3,4);
      A(76,25) = M(3,4);
      A(77,47) = M(3,4);
      A(78,49) = M(3,4);
      A(79,52) = M(3,4);
      A(80,32) = M(3,4);
      A(81,29) = M(3,4);
      A(82,54) = M(3,4);
      A(83,53) = M(3,4);
      A(84,40) = M(3,4);
      A(85,44) = M(3,4);
      A(86,43) = M(3,4);
      A(87,48) = M(3,4);
      A(88,28) = M(3,4);
      A(89,17) = M(3,4);
      A(90,42) = M(3,4);
      A(91,22) = M(3,4);
      A(92,46) = M(3,4);
      A(93,39) = M(3,4);
      A(94,24) = M(3,4);
      A(95,14) = M(3,4);
      A(96,27) = M(3,4);
      A(97,9) = M(3,4);
      A(98,19) = M(3,4);
      A(99,8) = M(3,4);
      A(100,34) = M(3,4);
      A(101,31) = M(3,4);
      A(102,6) = M(3,4);
      A(103,12) = M(3,4);
      A(104,3) = M(3,4);
      A(105,51) = M(3,4);
      A(71,58) = M(3,5);
      A(72,76) = M(3,5);
      A(73,28) = M(3,5);
      A(74,48) = M(3,5);
      A(75,25) = M(3,5);
      A(76,40) = M(3,5);
      A(77,68) = M(3,5);
      A(78,70) = M(3,5);
      A(79,73) = M(3,5);
      A(80,47) = M(3,5);
      A(81,44) = M(3,5);
      A(82,75) = M(3,5);
      A(83,74) = M(3,5);
      A(84,61) = M(3,5);
      A(85,65) = M(3,5);
      A(86,64) = M(3,5);
      A(87,69) = M(3,5);
      A(88,43) = M(3,5);
      A(89,27) = M(3,5);
      A(90,63) = M(3,5);
      A(91,37) = M(3,5);
      A(92,67) = M(3,5);
      A(93,60) = M(3,5);
      A(94,39) = M(3,5);
      A(95,24) = M(3,5);
      A(96,42) = M(3,5);
      A(97,15) = M(3,5);
      A(98,29) = M(3,5);
      A(99,14) = M(3,5);
      A(100,49) = M(3,5);
      A(101,46) = M(3,5);
      A(102,12) = M(3,5);
      A(103,22) = M(3,5);
      A(104,6) = M(3,5);
      A(105,72) = M(3,5);
      A(71,60) = M(3,6);
      A(72,82) = M(3,6);
      A(73,32) = M(3,6);
      A(74,53) = M(3,6);
      A(75,28) = M(3,6);
      A(76,43) = M(3,6);
      A(77,73) = M(3,6);
      A(78,75) = M(3,6);
      A(79,79) = M(3,6);
      A(80,52) = M(3,6);
      A(81,48) = M(3,6);
      A(82,81) = M(3,6);
      A(83,80) = M(3,6);
      A(84,64) = M(3,6);
      A(85,69) = M(3,6);
      A(86,68) = M(3,6);
      A(87,74) = M(3,6);
      A(88,47) = M(3,6);
      A(89,31) = M(3,6);
      A(90,67) = M(3,6);
      A(91,39) = M(3,6);
      A(92,72) = M(3,6);
      A(93,63) = M(3,6);
      A(94,42) = M(3,6);
      A(95,27) = M(3,6);
      A(96,46) = M(3,6);
      A(97,18) = M(3,6);
      A(98,33) = M(3,6);
      A(99,17) = M(3,6);
      A(100,54) = M(3,6);
      A(101,51) = M(3,6);
      A(102,14) = M(3,6);
      A(103,24) = M(3,6);
      A(104,8) = M(3,6);
      A(105,78) = M(3,6);
      A(71,38) = M(3,7);
      A(72,56) = M(3,7);
      A(73,19) = M(3,7);
      A(74,34) = M(3,7);
      A(75,16) = M(3,7);
      A(76,26) = M(3,7);
      A(77,48) = M(3,7);
      A(78,50) = M(3,7);
      A(79,53) = M(3,7);
      A(80,33) = M(3,7);
      A(81,30) = M(3,7);
      A(82,55) = M(3,7);
      A(83,54) = M(3,7);
      A(84,41) = M(3,7);
      A(85,45) = M(3,7);
      A(86,44) = M(3,7);
      A(87,49) = M(3,7);
      A(88,29) = M(3,7);
      A(89,18) = M(3,7);
      A(90,43) = M(3,7);
      A(91,23) = M(3,7);
      A(92,47) = M(3,7);
      A(93,40) = M(3,7);
      A(94,25) = M(3,7);
      A(95,15) = M(3,7);
      A(96,28) = M(3,7);
      A(97,10) = M(3,7);
      A(98,20) = M(3,7);
      A(99,9) = M(3,7);
      A(100,35) = M(3,7);
      A(101,32) = M(3,7);
      A(102,7) = M(3,7);
      A(103,13) = M(3,7);
      A(104,4) = M(3,7);
      A(105,52) = M(3,7);
      A(71,59) = M(3,8);
      A(72,77) = M(3,8);
      A(73,29) = M(3,8);
      A(74,49) = M(3,8);
      A(75,26) = M(3,8);
      A(76,41) = M(3,8);
      A(77,69) = M(3,8);
      A(78,71) = M(3,8);
      A(79,74) = M(3,8);
      A(80,48) = M(3,8);
      A(81,45) = M(3,8);
      A(82,76) = M(3,8);
      A(83,75) = M(3,8);
      A(84,62) = M(3,8);
      A(85,66) = M(3,8);
      A(86,65) = M(3,8);
      A(87,70) = M(3,8);
      A(88,44) = M(3,8);
      A(89,28) = M(3,8);
      A(90,64) = M(3,8);
      A(91,38) = M(3,8);
      A(92,68) = M(3,8);
      A(93,61) = M(3,8);
      A(94,40) = M(3,8);
      A(95,25) = M(3,8);
      A(96,43) = M(3,8);
      A(97,16) = M(3,8);
      A(98,30) = M(3,8);
      A(99,15) = M(3,8);
      A(100,50) = M(3,8);
      A(101,47) = M(3,8);
      A(102,13) = M(3,8);
      A(103,23) = M(3,8);
      A(104,7) = M(3,8);
      A(105,73) = M(3,8);
      A(71,61) = M(3,9);
      A(72,83) = M(3,9);
      A(73,33) = M(3,9);
      A(74,54) = M(3,9);
      A(75,29) = M(3,9);
      A(76,44) = M(3,9);
      A(77,74) = M(3,9);
      A(78,76) = M(3,9);
      A(79,80) = M(3,9);
      A(80,53) = M(3,9);
      A(81,49) = M(3,9);
      A(82,82) = M(3,9);
      A(83,81) = M(3,9);
      A(84,65) = M(3,9);
      A(85,70) = M(3,9);
      A(86,69) = M(3,9);
      A(87,75) = M(3,9);
      A(88,48) = M(3,9);
      A(89,32) = M(3,9);
      A(90,68) = M(3,9);
      A(91,40) = M(3,9);
      A(92,73) = M(3,9);
      A(93,64) = M(3,9);
      A(94,43) = M(3,9);
      A(95,28) = M(3,9);
      A(96,47) = M(3,9);
      A(97,19) = M(3,9);
      A(98,34) = M(3,9);
      A(99,18) = M(3,9);
      A(100,55) = M(3,9);
      A(101,52) = M(3,9);
      A(102,15) = M(3,9);
      A(103,25) = M(3,9);
      A(104,9) = M(3,9);
      A(105,79) = M(3,9);
      A(71,62) = M(3,10);
      A(72,84) = M(3,10);
      A(73,34) = M(3,10);
      A(74,55) = M(3,10);
      A(75,30) = M(3,10);
      A(76,45) = M(3,10);
      A(77,75) = M(3,10);
      A(78,77) = M(3,10);
      A(79,81) = M(3,10);
      A(80,54) = M(3,10);
      A(81,50) = M(3,10);
      A(82,83) = M(3,10);
      A(83,82) = M(3,10);
      A(84,66) = M(3,10);
      A(85,71) = M(3,10);
      A(86,70) = M(3,10);
      A(87,76) = M(3,10);
      A(88,49) = M(3,10);
      A(89,33) = M(3,10);
      A(90,69) = M(3,10);
      A(91,41) = M(3,10);
      A(92,74) = M(3,10);
      A(93,65) = M(3,10);
      A(94,44) = M(3,10);
      A(95,29) = M(3,10);
      A(96,48) = M(3,10);
      A(97,20) = M(3,10);
      A(98,35) = M(3,10);
      A(99,19) = M(3,10);
      A(100,56) = M(3,10);
      A(101,53) = M(3,10);
      A(102,16) = M(3,10);
      A(103,26) = M(3,10);
      A(104,10) = M(3,10);
      A(105,80) = M(3,10);
      A(106,21) = M(4,1);
      A(107,35) = M(4,1);
      A(108,9) = M(4,1);
      A(109,19) = M(4,1);
      A(110,7) = M(4,1);
      A(111,13) = M(4,1);
      A(112,28) = M(4,1);
      A(113,30) = M(4,1);
      A(114,32) = M(4,1);
      A(115,18) = M(4,1);
      A(116,16) = M(4,1);
      A(117,34) = M(4,1);
      A(118,33) = M(4,1);
      A(119,23) = M(4,1);
      A(120,26) = M(4,1);
      A(121,25) = M(4,1);
      A(122,29) = M(4,1);
      A(123,15) = M(4,1);
      A(124,8) = M(4,1);
      A(125,24) = M(4,1);
      A(126,11) = M(4,1);
      A(127,27) = M(4,1);
      A(128,22) = M(4,1);
      A(129,12) = M(4,1);
      A(130,6) = M(4,1);
      A(131,14) = M(4,1);
      A(132,4) = M(4,1);
      A(133,10) = M(4,1);
      A(134,3) = M(4,1);
      A(135,20) = M(4,1);
      A(136,17) = M(4,1);
      A(137,2) = M(4,1);
      A(138,5) = M(4,1);
      A(139,1) = M(4,1);
      A(140,31) = M(4,1);
      A(106,36) = M(4,2);
      A(107,50) = M(4,2);
      A(108,15) = M(4,2);
      A(109,29) = M(4,2);
      A(110,13) = M(4,2);
      A(111,23) = M(4,2);
      A(112,43) = M(4,2);
      A(113,45) = M(4,2);
      A(114,47) = M(4,2);
      A(115,28) = M(4,2);
      A(116,26) = M(4,2);
      A(117,49) = M(4,2);
      A(118,48) = M(4,2);
      A(119,38) = M(4,2);
      A(120,41) = M(4,2);
      A(121,40) = M(4,2);
      A(122,44) = M(4,2);
      A(123,25) = M(4,2);
      A(124,14) = M(4,2);
      A(125,39) = M(4,2);
      A(126,21) = M(4,2);
      A(127,42) = M(4,2);
      A(128,37) = M(4,2);
      A(129,22) = M(4,2);
      A(130,12) = M(4,2);
      A(131,24) = M(4,2);
      A(132,7) = M(4,2);
      A(133,16) = M(4,2);
      A(134,6) = M(4,2);
      A(135,30) = M(4,2);
      A(136,27) = M(4,2);
      A(137,5) = M(4,2);
      A(138,11) = M(4,2);
      A(139,2) = M(4,2);
      A(140,46) = M(4,2);
      A(106,57) = M(4,3);
      A(107,71) = M(4,3);
      A(108,25) = M(4,3);
      A(109,44) = M(4,3);
      A(110,23) = M(4,3);
      A(111,38) = M(4,3);
      A(112,64) = M(4,3);
      A(113,66) = M(4,3);
      A(114,68) = M(4,3);
      A(115,43) = M(4,3);
      A(116,41) = M(4,3);
      A(117,70) = M(4,3);
      A(118,69) = M(4,3);
      A(119,59) = M(4,3);
      A(120,62) = M(4,3);
      A(121,61) = M(4,3);
      A(122,65) = M(4,3);
      A(123,40) = M(4,3);
      A(124,24) = M(4,3);
      A(125,60) = M(4,3);
      A(126,36) = M(4,3);
      A(127,63) = M(4,3);
      A(128,58) = M(4,3);
      A(129,37) = M(4,3);
      A(130,22) = M(4,3);
      A(131,39) = M(4,3);
      A(132,13) = M(4,3);
      A(133,26) = M(4,3);
      A(134,12) = M(4,3);
      A(135,45) = M(4,3);
      A(136,42) = M(4,3);
      A(137,11) = M(4,3);
      A(138,21) = M(4,3);
      A(139,5) = M(4,3);
      A(140,67) = M(4,3);
      A(106,37) = M(4,4);
      A(107,55) = M(4,4);
      A(108,18) = M(4,4);
      A(109,33) = M(4,4);
      A(110,15) = M(4,4);
      A(111,25) = M(4,4);
      A(112,47) = M(4,4);
      A(113,49) = M(4,4);
      A(114,52) = M(4,4);
      A(115,32) = M(4,4);
      A(116,29) = M(4,4);
      A(117,54) = M(4,4);
      A(118,53) = M(4,4);
      A(119,40) = M(4,4);
      A(120,44) = M(4,4);
      A(121,43) = M(4,4);
      A(122,48) = M(4,4);
      A(123,28) = M(4,4);
      A(124,17) = M(4,4);
      A(125,42) = M(4,4);
      A(126,22) = M(4,4);
      A(127,46) = M(4,4);
      A(128,39) = M(4,4);
      A(129,24) = M(4,4);
      A(130,14) = M(4,4);
      A(131,27) = M(4,4);
      A(132,9) = M(4,4);
      A(133,19) = M(4,4);
      A(134,8) = M(4,4);
      A(135,34) = M(4,4);
      A(136,31) = M(4,4);
      A(137,6) = M(4,4);
      A(138,12) = M(4,4);
      A(139,3) = M(4,4);
      A(140,51) = M(4,4);
      A(106,58) = M(4,5);
      A(107,76) = M(4,5);
      A(108,28) = M(4,5);
      A(109,48) = M(4,5);
      A(110,25) = M(4,5);
      A(111,40) = M(4,5);
      A(112,68) = M(4,5);
      A(113,70) = M(4,5);
      A(114,73) = M(4,5);
      A(115,47) = M(4,5);
      A(116,44) = M(4,5);
      A(117,75) = M(4,5);
      A(118,74) = M(4,5);
      A(119,61) = M(4,5);
      A(120,65) = M(4,5);
      A(121,64) = M(4,5);
      A(122,69) = M(4,5);
      A(123,43) = M(4,5);
      A(124,27) = M(4,5);
      A(125,63) = M(4,5);
      A(126,37) = M(4,5);
      A(127,67) = M(4,5);
      A(128,60) = M(4,5);
      A(129,39) = M(4,5);
      A(130,24) = M(4,5);
      A(131,42) = M(4,5);
      A(132,15) = M(4,5);
      A(133,29) = M(4,5);
      A(134,14) = M(4,5);
      A(135,49) = M(4,5);
      A(136,46) = M(4,5);
      A(137,12) = M(4,5);
      A(138,22) = M(4,5);
      A(139,6) = M(4,5);
      A(140,72) = M(4,5);
      A(106,60) = M(4,6);
      A(107,82) = M(4,6);
      A(108,32) = M(4,6);
      A(109,53) = M(4,6);
      A(110,28) = M(4,6);
      A(111,43) = M(4,6);
      A(112,73) = M(4,6);
      A(113,75) = M(4,6);
      A(114,79) = M(4,6);
      A(115,52) = M(4,6);
      A(116,48) = M(4,6);
      A(117,81) = M(4,6);
      A(118,80) = M(4,6);
      A(119,64) = M(4,6);
      A(120,69) = M(4,6);
      A(121,68) = M(4,6);
      A(122,74) = M(4,6);
      A(123,47) = M(4,6);
      A(124,31) = M(4,6);
      A(125,67) = M(4,6);
      A(126,39) = M(4,6);
      A(127,72) = M(4,6);
      A(128,63) = M(4,6);
      A(129,42) = M(4,6);
      A(130,27) = M(4,6);
      A(131,46) = M(4,6);
      A(132,18) = M(4,6);
      A(133,33) = M(4,6);
      A(134,17) = M(4,6);
      A(135,54) = M(4,6);
      A(136,51) = M(4,6);
      A(137,14) = M(4,6);
      A(138,24) = M(4,6);
      A(139,8) = M(4,6);
      A(140,78) = M(4,6);
      A(106,38) = M(4,7);
      A(107,56) = M(4,7);
      A(108,19) = M(4,7);
      A(109,34) = M(4,7);
      A(110,16) = M(4,7);
      A(111,26) = M(4,7);
      A(112,48) = M(4,7);
      A(113,50) = M(4,7);
      A(114,53) = M(4,7);
      A(115,33) = M(4,7);
      A(116,30) = M(4,7);
      A(117,55) = M(4,7);
      A(118,54) = M(4,7);
      A(119,41) = M(4,7);
      A(120,45) = M(4,7);
      A(121,44) = M(4,7);
      A(122,49) = M(4,7);
      A(123,29) = M(4,7);
      A(124,18) = M(4,7);
      A(125,43) = M(4,7);
      A(126,23) = M(4,7);
      A(127,47) = M(4,7);
      A(128,40) = M(4,7);
      A(129,25) = M(4,7);
      A(130,15) = M(4,7);
      A(131,28) = M(4,7);
      A(132,10) = M(4,7);
      A(133,20) = M(4,7);
      A(134,9) = M(4,7);
      A(135,35) = M(4,7);
      A(136,32) = M(4,7);
      A(137,7) = M(4,7);
      A(138,13) = M(4,7);
      A(139,4) = M(4,7);
      A(140,52) = M(4,7);
      A(106,59) = M(4,8);
      A(107,77) = M(4,8);
      A(108,29) = M(4,8);
      A(109,49) = M(4,8);
      A(110,26) = M(4,8);
      A(111,41) = M(4,8);
      A(112,69) = M(4,8);
      A(113,71) = M(4,8);
      A(114,74) = M(4,8);
      A(115,48) = M(4,8);
      A(116,45) = M(4,8);
      A(117,76) = M(4,8);
      A(118,75) = M(4,8);
      A(119,62) = M(4,8);
      A(120,66) = M(4,8);
      A(121,65) = M(4,8);
      A(122,70) = M(4,8);
      A(123,44) = M(4,8);
      A(124,28) = M(4,8);
      A(125,64) = M(4,8);
      A(126,38) = M(4,8);
      A(127,68) = M(4,8);
      A(128,61) = M(4,8);
      A(129,40) = M(4,8);
      A(130,25) = M(4,8);
      A(131,43) = M(4,8);
      A(132,16) = M(4,8);
      A(133,30) = M(4,8);
      A(134,15) = M(4,8);
      A(135,50) = M(4,8);
      A(136,47) = M(4,8);
      A(137,13) = M(4,8);
      A(138,23) = M(4,8);
      A(139,7) = M(4,8);
      A(140,73) = M(4,8);
      A(106,61) = M(4,9);
      A(107,83) = M(4,9);
      A(108,33) = M(4,9);
      A(109,54) = M(4,9);
      A(110,29) = M(4,9);
      A(111,44) = M(4,9);
      A(112,74) = M(4,9);
      A(113,76) = M(4,9);
      A(114,80) = M(4,9);
      A(115,53) = M(4,9);
      A(116,49) = M(4,9);
      A(117,82) = M(4,9);
      A(118,81) = M(4,9);
      A(119,65) = M(4,9);
      A(120,70) = M(4,9);
      A(121,69) = M(4,9);
      A(122,75) = M(4,9);
      A(123,48) = M(4,9);
      A(124,32) = M(4,9);
      A(125,68) = M(4,9);
      A(126,40) = M(4,9);
      A(127,73) = M(4,9);
      A(128,64) = M(4,9);
      A(129,43) = M(4,9);
      A(130,28) = M(4,9);
      A(131,47) = M(4,9);
      A(132,19) = M(4,9);
      A(133,34) = M(4,9);
      A(134,18) = M(4,9);
      A(135,55) = M(4,9);
      A(136,52) = M(4,9);
      A(137,15) = M(4,9);
      A(138,25) = M(4,9);
      A(139,9) = M(4,9);
      A(140,79) = M(4,9);
      A(106,62) = M(4,10);
      A(107,84) = M(4,10);
      A(108,34) = M(4,10);
      A(109,55) = M(4,10);
      A(110,30) = M(4,10);
      A(111,45) = M(4,10);
      A(112,75) = M(4,10);
      A(113,77) = M(4,10);
      A(114,81) = M(4,10);
      A(115,54) = M(4,10);
      A(116,50) = M(4,10);
      A(117,83) = M(4,10);
      A(118,82) = M(4,10);
      A(119,66) = M(4,10);
      A(120,71) = M(4,10);
      A(121,70) = M(4,10);
      A(122,76) = M(4,10);
      A(123,49) = M(4,10);
      A(124,33) = M(4,10);
      A(125,69) = M(4,10);
      A(126,41) = M(4,10);
      A(127,74) = M(4,10);
      A(128,65) = M(4,10);
      A(129,44) = M(4,10);
      A(130,29) = M(4,10);
      A(131,48) = M(4,10);
      A(132,20) = M(4,10);
      A(133,35) = M(4,10);
      A(134,19) = M(4,10);
      A(135,56) = M(4,10);
      A(136,53) = M(4,10);
      A(137,16) = M(4,10);
      A(138,26) = M(4,10);
      A(139,10) = M(4,10);
      A(140,80) = M(4,10);

   [U,S,V] = svd(A);
   S = diag(S)'
   cond = [S(m-1)/S(1), S(m)/S(m-1)];
   v = V(:,m);
   % v = v .* D';

   % To get most accurate ratios of u.i's, select largest 
   % column from uu = const * [u1;u2;u3;u4] * [u1^2*u2*u3,u2^4,u3^4,u4^4]

   uu = [v([ 1,  3,  4, 19]), ...
         v([ 6, 11, 12, 25]), ...
	 v([10, 15, 16, 29]), ...
	 v([46, 47, 48, 49])];

   nu = sum(uu.^2);
   % uu ./ (ones(4,1)*sqrt(nu))
   i = 1;
   for j=2:4 
      if (nu(j)>nu(i)) i=j; end;
   end;
   u = uu(:,i);
end;
